@@ -20,8 +20,13 @@ class InspectDataclass:
 
     def extract_meta(
         self,
-    ) -> tuple[str | None, list[str] | None, dict[str, dict[str, tp.Any]] | None]:
-        pk_key, unique_together, extra_kwgs = None, None, None
+    ) -> tuple[
+        str | None,
+        list[str] | None,
+        dict[str, dict[str, tp.Any]] | None,
+        list[str] | None,
+    ]:
+        pk_key, unique_together, extra_kwgs, ordering = None, None, None, None
         if hasattr(self.dataclass, "Meta"):
             meta = self.dataclass.Meta  # type: ignore
             if hasattr(meta, "primary_key"):
@@ -33,11 +38,14 @@ class InspectDataclass:
             if hasattr(meta, "extra"):
                 extra_kwgs = meta.extra
                 assert isinstance(extra_kwgs, dict)
+            if hasattr(meta, "ordering"):
+                ordering = meta.ordering
+                assert isinstance(ordering, list)
 
-        return pk_key, unique_together, extra_kwgs
+        return pk_key, unique_together, extra_kwgs, ordering
 
     def get_identifying_parameter(self) -> set[str]:
-        pk_key, unique_together, _ = self.extract_meta()
+        pk_key, unique_together, _, _ = self.extract_meta()
         res = set()
         if pk_key is not None:
             res.add(pk_key)
@@ -50,10 +58,10 @@ class InspectDataclass:
 class CreateDjangoModel(InspectDataclass):
     def __post_init__(self) -> None:
         # evaluate the Meta class
-        pk_key, unique_together, extra_kwgs = self.extract_meta()
+        pk_key, unique_together, extra_kwgs, ordering = self.extract_meta()
         # translate fields
         fields: dict[str, tp.Any] = self.translate_fields(pk_key, extra_kwgs)
-        fields["Meta"] = self.generate_meta(unique_together)
+        fields["Meta"] = self.generate_meta(unique_together, ordering)
         # pylint: disable=comparison-with-callable
         if self.dataclass.__str__ != object.__str__:  # type: ignore
             fields["__str__"] = self.dataclass.__str__
@@ -84,7 +92,9 @@ class CreateDjangoModel(InspectDataclass):
             )
         return fields
 
-    def generate_meta(self, unique_together: list[str] | None) -> type:
+    def generate_meta(
+        self, unique_together: list[str] | None, ordering: list[str] | None
+    ) -> type:
         class Meta:
             app_label = public_name(self.dataclass, without_cls=True)
             db_table = public_name(self.dataclass)
@@ -92,6 +102,9 @@ class CreateDjangoModel(InspectDataclass):
         if unique_together:
             Meta.unique_together = unique_together  # type: ignore
 
+        if ordering:
+            Meta.ordering = ordering  # type: ignore
+
         return Meta
 
     @classmethod
