@@ -22,7 +22,12 @@ class BackendLinker:
             dataclass = dc_obj_or_dataclass
         else:
             dataclass = type(dc_obj_or_dataclass)
-        return self.dc_to_backend[dataclass]
+        try:
+            return self.dc_to_backend[dataclass]
+        except KeyError as err:
+            raise KeyError(
+                f"{dataclass} not found, have you forgotten to admem.create_django_model or similar?"
+            ) from err
 
     def django_backend_classes(self) -> tp.Iterator[type[models.Model]]:
         for key in self.backend_to_dc:
