@@ -8,7 +8,7 @@ class BackendStoreProtocol(tp.Protocol):
     def dump(self, obj: T) -> tp.Any:
         pass  # pragma: no cover
 
-    def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
+    def load_all(self, dataclass: type[T], **filter_kwgs: tp.Any) -> tp.Iterator[T]:
         pass  # pragma: no cover
 
     def parse(self, backend_obj: tp.Any) -> tp.Any:
