@@ -27,8 +27,18 @@ class SyncStore:
         _, created = self.impl.dump(obj)
         return created  # type: ignore
 
+    def load_all(self, dataclass: type[T], **filter_kwgs: tp.Any) -> tp.Iterator[T]:
+        yield from self.impl.load_all(dataclass, **filter_kwgs)
+
     def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
-        return self.impl.load(dataclass, **filter_kwgs)
+        hits = list(self.load_all(dataclass, **filter_kwgs))
+        if len(hits) > 1:
+            raise RuntimeError(
+                f"found {len(hits)} entries matching filter_kwgs {filter_kwgs}, be more specific!"
+            )
+        if len(hits) == 0:
+            raise RuntimeError(f"found no entries matching filter_kwgs {filter_kwgs}!")
+        return hits[0]
 
     def __getitem__(self, dataclass: type[T]) -> BackendManagerProxy:
         return BackendManagerProxy(self.impl, self.impl.backend_manager(dataclass))
